@@ -129,11 +129,6 @@ class MTWandbArtifactCallback(pl.callbacks.Callback):
         self.pl_model_params = pl_model_params
 
     def on_train_start(self, trainer, pl_module):
-        # src zip
-        shutil.make_archive(f"{self.model_dir}/src", "zip", "../../src")
-        src_artifact = wandb.Artifact("src", type="src_zip")
-        src_artifact.add_file(f"{self.model_dir}/src.zip")
-        self.wandb_run.log_artifact(src_artifact, aliases=[self.wandb_run.name])
         # lookup files
         lookup_artifact = wandb.Artifact("lookup_csv", type="lookup_tables")
         lookup_artifact.add_dir(self.lookup_output_dir)
